@@ -40,8 +40,9 @@ use Net::Amazon::EMR::ScriptBootstrapActionConfig;
 use Net::Amazon::EMR::StepConfig;
 use Net::Amazon::EMR::StepDetail;
 use Net::Amazon::EMR::StepExecutionStatusDetail;
+use Net::Amazon::EMR::SupportedProductConfig;
 
-our $VERSION = '0.17';
+our $VERSION = '0.19';
 
 has 'AWSAccessKeyId'    => ( is => 'ro', isa => 'Str', required => 1 );
 has 'SecretAccessKey'   => ( is => 'ro', isa => 'Str', required => 1 );
@@ -276,10 +277,16 @@ sub run_job_flow {
                               optional => 1, 
                               coerce => 1 },
         Instances       => { isa => 'Net::Amazon::EMR::Type::JobFlowInstancesConfig', coerce => 1 },
+        JobFlowRole  => { isa => 'Str | Undef', optional => 1 },
         LogUri  => { isa => 'Str | Undef', optional => 1 },
         Name    => { isa => 'Str' },
+        NewSupportedProducts => { isa => 'Net::Amazon::EMR::Type::ArrayRefofSupportedProductConfig | Undef', 
+                              optional => 1, 
+                              coerce => 1 },
+        ServiceRole  => { isa => 'Str | Undef', optional => 1 },
         Steps   => { isa => 'Net::Amazon::EMR::Type::ArrayRefofStepConfig', optional => 1, coerce => 1 },
         SupportedProducts => { isa => 'ArrayRef[Str] | Undef', optional => 1 },
+        Tags => { isa => 'ArrayRef[Str] | Undef', optional => 1 },
         VisibleToAllUsers => { isa => 'Net::Amazon::EMR::Type::Bool', optional => 1 },
                                         );
 
